import { ArrayIteratee, Nil, ObjectIteratee } from '../interfaces';
/**
 * Maps `collection` to be the keys of a new object, with the values determined by `iteratee`.
 *
 * ```ts
 * mapAsKeys([1, 2, 3], (item) => item * item);
 * // result: { 1: 1, 2: 4, 3: 9 }
 *
 * mapAsKeys({ a: "foo", b: "bar" }, (_item, key) => key.toUpperCase());
 * // result: { foo: "A", bar: "B" }
 * ```
 */
export declare function mapAsKeys<K extends keyof any, V>(array: K[], iteratee: ArrayIteratee<K, V>): {
    [k in K]: V;
};
export declare function mapAsKeys<K extends keyof any, V>(array: K[] | Nil, iteratee: ArrayIteratee<K, V>): {
    [k in K]: V;
} | {};
export declare function mapAsKeys<T extends Record<keyof T, keyof any>, V>(object: T, iteratee: ObjectIteratee<T, V>): {
    [k in T[keyof T]]: V;
};
export declare function mapAsKeys<T extends Record<keyof T, keyof any>, V>(object: T | Nil, iteratee: ObjectIteratee<T, V>): {
    [k in T[keyof T]]: V;
} | {};
